┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/statusbar/spaceinfoobserver.h
diff options
context:
space:
mode:
authorMathias Tillman <[email protected]>2014-09-14 18:53:05 +0200
committerMathias Tillman <[email protected]>2014-09-14 18:53:05 +0200
commitd380d27f47a67e6e682a4b980c66585f13a3d7b5 (patch)
tree5c6c117e085192bf19e0da402e8a5ce00741366e /src/statusbar/spaceinfoobserver.h
parent4de8cf43e62e23b766d9d457e060670401ce6128 (diff)
Make the statusbar space info use the new KIO::fileSystemFreeSpace job.
REVIEW: 120137 BUG: 245226
Diffstat (limited to 'src/statusbar/spaceinfoobserver.h')
-rw-r--r--src/statusbar/spaceinfoobserver.h10
1 files changed, 9 insertions, 1 deletions
diff --git a/src/statusbar/spaceinfoobserver.h b/src/statusbar/spaceinfoobserver.h
index d2fb6ebf3..68c559ec9 100644
--- a/src/statusbar/spaceinfoobserver.h
+++ b/src/statusbar/spaceinfoobserver.h
@@ -22,6 +22,8 @@
#include <QObject>
+#include <KIO/Job>
+
class KUrl;
class MountPointObserver;
@@ -40,12 +42,18 @@ public:
signals:
/**
* This signal is emitted if the information that size() and/or available() will return has changed.
*/
void valuesChanged();
+private slots:
+ void spaceInfoChanged(quint64 size, quint64 available);
+
private:
MountPointObserver* m_mountPointObserver;
+
+ quint64 m_dataSize;
+ quint64 m_dataAvailable;
};
#endif
@@ -40,12 +42,18 @@ public:
signals:
/**
- * This signal is emitted if the information that size() and/or available() will return has changed.
+ * This signal is emitted when the size or available space changes.
*/
void valuesChanged();